-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftNPCTagData")
local gratuity = AceLibrary("Gratuity-2.0")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Save NPC Tag Data"] = true,
	["Stores NPC tag data between sessions"] = true,
	
	["Level"] = true,
} end)

-----------------------------------------------------------------------------

local npcTags = { }

-----------------------------------------------------------------------------

local AloftNPCTagData = Aloft:NewModule("NPCTagData", "AceEvent-2.0")
AloftNPCTagData.db = Aloft:AcquireDBNamespace("npcTag")
Aloft:RegisterDefaults("npcTag", "account", { npcTags = { } })
Aloft:RegisterDefaults("npcTag", "profile", { save = true })

-----------------------------------------------------------------------------

Aloft.Options.args.data.args.npcTag =
{
	type = 'toggle',
	name = L["Save NPC Tag Data"],
	desc = L["Stores NPC tag data between sessions"],
	get = function() return AloftNPCTagData.db.profile.save end,
	set = function(v)
			AloftNPCTagData.db.profile.save = v
			if v then
				AloftNPCTagData.db.server.npcTags = npcTags
			else
				AloftNPCTagData.db.server.npcTags = { }
			end
		  end,
}


-----------------------------------------------------------------------------

AloftTagDirectAccessData.npcTag = true
AloftTagData.npcTag = { data = "npcTag", events = "Aloft:OnNPCTagDataChanged" }

function AloftNPCTagData:ProvidesData()
	return "npcTag"
end

function AloftNPCTagData:EnableDataSource()
    self:RegisterEvent("UPDATE_MOUSEOVER_UNIT", "UpdateNPCTagFromMouseOver")
    self:RegisterEvent("PLAYER_TARGET_CHANGED", "UpdateNPCTagFromTarget")
end

-----------------------------------------------------------------------------

function AloftNPCTagData:OnEnable()
	if self.db.profile.save then
		npcTags = self.db.account.npcTags
	end
end

function AloftNPCTagData:UpdateData(aloftData)
	aloftData.npcTag = npcTags[aloftData.name]
end

-----------------------------------------------------------------------------

function AloftNPCTagData:UpdateNPCTagFromUnit(unitid)
	if UnitIsFriend("player", unitid) and not UnitPlayerControlled(unitid) then
		gratuity:SetUnit(unitid)
		local npcTag = gratuity:GetLine(2)
		
		if npcTag and npcTag ~= "" and npcTag:find(L["Level"]) ~= 1 then
			local key = UnitName(unitid)
			if npcTags[key] ~= npcTag then
				npcTags[key] = npcTag

				for aloftData in Aloft:IterateVisibleNameplates() do
					if aloftData.name == key then
						aloftData.npcTag = npcTag
						self:TriggerEvent("Aloft:OnNPCTagDataChanged", aloftData)
					end
				end
			end
		end
	end
end

-----------------------------------------------------------------------------

function AloftNPCTagData:UpdateNPCTagFromMouseOver()
	self:UpdateNPCTagFromUnit("mouseover")
end

function AloftNPCTagData:UpdateNPCTagFromTarget()
	self:UpdateNPCTagFromUnit("target")
end

-----------------------------------------------------------------------------
